 /*----------------------------------------------------------------------------------------------------+
 |                             National Institute of Standards and Technology                          |
 |                                        Biometric Clients Lab                                        |
 +-----------------------------------------------------------------------------------------------------+
  File author(s):
       Kevin Mangold (kevin.mangold@nist.gov)
 
 +-----------------------------------------------------------------------------------------------------+
 | NOTICE & DISCLAIMER                                                                                 |
 |                                                                                                     |
 | The research software provided on this web site ("software") is provided by NIST as a public        |
 | service. You may use, copy and distribute copies of the software in any medium, provided that you   |
 | keep intact this entire notice. You may improve, modify and create derivative works of the software |
 | or any portion of the software, and you may copy and distribute such modifications or works.        |
 | Modified works should carry a notice stating that you changed the software and should note the date |
 | and nature of any such change.  Please explicitly acknowledge the National Institute of Standards   |
 | and Technology as the source of the software.                                                       |
 |                                                                                                     |
 | The software is expressly provided "AS IS."  NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED,  |
 | IN FACT OR ARISING BY OPERATION OF LAW, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTY OF      |
 | MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY.  NIST        |
 | NEITHER REPRESENTS NOR WARRANTS THAT THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR         |
 | ERROR-FREE, OR THAT ANY DEFECTS WILL BE CORRECTED.  NIST DOES NOT WARRANT OR MAKE ANY               |
 | REPRESENTATIONS REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED |
 | TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.                           |
 |                                                                                                     |
 | You are solely responsible for determining the appropriateness of using and distributing the        |
 | software and you assume all risks associated with its use, including but not limited to the risks   |
 | and costs of program errors, compliance with applicable laws, damage to or loss of data, programs   |
 | or equipment, and the unavailability or interruption of operation.  This software is not intended   |
 | to be used in any situation where a failure could cause risk of injury or damage to property.  The  |
 | software was developed by NIST employees.  NIST employee contributions are not subject to copyright |
 | protection within the United States.                                                                |
 |                                                                                                     |
 | Specific hardware and software products identified in this open source project were used in order   |
 | to perform technology transfer and collaboration. In no case does such identification imply         |
 | recommendation or endorsement by the National Institute of Standards and Technology, nor            |
 | does it imply that the products and equipment identified are necessarily the best available for the |
 | purpose.                                                                                            |
 +----------------------------------------------------------------------------------------------------*/

package gov.nist.itl.wsbd;

import java.util.Calendar;

public class Logging {
	public static final boolean GLOBAL = true;
	public static final boolean TIMESTAMP = true;
	public static final boolean DEBUG = true && GLOBAL;
	public static final boolean TRACE = true && GLOBAL;

	protected static final void log(boolean flag, String level, String format, Object... args) {
		if (flag) {
			String pretext = String.format("[%1$ 3d] ", Thread.currentThread().getId());
			
			if (TIMESTAMP) {
				pretext = String.format("%1$s%2$s ", pretext, timestamp());
			}
			
			System.out.printf("%1$s%2$s: %3$s%n", pretext, level, String.format(format, args));
		}
	}
	
	public static final String timestamp() {
		return String.format("[%1$tY-%1$tm-%1$te %1$tH:%1$tM:%1$tS.%1$tL]", Calendar.getInstance());
	}
	
	public static final void trace(String format, Object... args) {
		log(TRACE, "TRACE", format, args);
	}	

	public static final void trace(Object obj) {
		trace("%s", obj.toString());
	}
	
	public static void trace() {
		StackTraceElement[] elements = Thread.currentThread().getStackTrace();
		int index = 2;
		
		int lineNumber = elements[index].getLineNumber();
		String methodName = elements[index].getMethodName();
		String className = elements[index].getClassName();
		log(TRACE, "TRACE", "%s.%s()", className, methodName, lineNumber);
	}
	
	public static final void debug(String format, Object... args) {
		log(DEBUG, "DEBUG", format, args);
	}
	
	public static final void debug(Object obj) {
		debug("%s", obj.toString());
	}
}