 /*----------------------------------------------------------------------------------------------------+
 |                             National Institute of Standards and Technology                          |
 |                                        Biometric Clients Lab                                        |
 +-----------------------------------------------------------------------------------------------------+
  File author(s):
       Kevin Mangold (kevin.mangold@nist.gov)
 
 +-----------------------------------------------------------------------------------------------------+
 | NOTICE & DISCLAIMER                                                                                 |
 |                                                                                                     |
 | The research software provided on this web site ("software") is provided by NIST as a public        |
 | service. You may use, copy and distribute copies of the software in any medium, provided that you   |
 | keep intact this entire notice. You may improve, modify and create derivative works of the software |
 | or any portion of the software, and you may copy and distribute such modifications or works.        |
 | Modified works should carry a notice stating that you changed the software and should note the date |
 | and nature of any such change.  Please explicitly acknowledge the National Institute of Standards   |
 | and Technology as the source of the software.                                                       |
 |                                                                                                     |
 | The software is expressly provided "AS IS."  NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED,  |
 | IN FACT OR ARISING BY OPERATION OF LAW, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTY OF      |
 | MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY.  NIST        |
 | NEITHER REPRESENTS NOR WARRANTS THAT THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR         |
 | ERROR-FREE, OR THAT ANY DEFECTS WILL BE CORRECTED.  NIST DOES NOT WARRANT OR MAKE ANY               |
 | REPRESENTATIONS REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED |
 | TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.                           |
 |                                                                                                     |
 | You are solely responsible for determining the appropriateness of using and distributing the        |
 | software and you assume all risks associated with its use, including but not limited to the risks   |
 | and costs of program errors, compliance with applicable laws, damage to or loss of data, programs   |
 | or equipment, and the unavailability or interruption of operation.  This software is not intended   |
 | to be used in any situation where a failure could cause risk of injury or damage to property.  The  |
 | software was developed by NIST employees.  NIST employee contributions are not subject to copyright |
 | protection within the United States.                                                                |
 |                                                                                                     |
 | Specific hardware and software products identified in this open source project were used in order   |
 | to perform technology transfer and collaboration. In no case does such identification imply         |
 | recommendation or endorsement by the National Institute of Standards and Technology, nor            |
 | does it imply that the products and equipment identified are necessarily the best available for the |
 | purpose.                                                                                            |
 +----------------------------------------------------------------------------------------------------*/

package gov.nist.itl.wsbd.streaming;

import gov.nist.itl.wsbd.Logging;

import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.UUID;

public class WsbdStream extends InputStream {
	protected final String id;
	protected int maxFramesPerSecond = 20;
	protected int maxBufferSize = 1024 * 5;
	
	protected StreamPool targetPool;
	protected String boundary;
	
	protected byte[] frame;
	protected String contentType;
	protected int position;
	
	public WsbdStream(String boundary) {
		this.boundary = boundary;
		id = UUID.randomUUID().toString();
		
		System.out.printf("%s opened at %s%n", id, Logging.timestamp());
	}
	
	public void setLatestFrame(byte[] frame, String contentType) {
		this.frame = frame;
		this.contentType = contentType;
	}

	public void copyLatestFrame() {
		try {
			Thread.sleep(1024 / maxFramesPerSecond);
			targetPool.copyLatestFrame(this);
		} catch (InterruptedException ie) {
			ie.printStackTrace();
		}
	}

	public int read(byte[] b, int off, int len) throws IOException {
		if (frame == null) {
			if (!targetPool.isFrameReady()) {
				return 1;
			}
			
			copyLatestFrame();
			
			if (frame == null) {
				return 1;
			}
			
			byte[] header = getHeader().getBytes(Charset.defaultCharset());
			System.arraycopy(header, 0, b, 0, header.length);
			
			return header.length;
		} else {
			
			int allowedBufferSize = Math.min(len, maxBufferSize);
			int bytesLeft = frame.length - position;
			int bytesRead = 0;
			
			if (bytesLeft < allowedBufferSize) {
				System.arraycopy(frame, position, b, 0, bytesLeft);
				bytesRead = bytesLeft;
				frame = null;
			} else {
				System.arraycopy(frame, position, b, 0, allowedBufferSize);
				bytesRead = allowedBufferSize;
			}
			
			position += bytesRead;
			System.out.printf("position: %d \t br: %d%n", position, bytesRead);
			
			return bytesRead;
		}
	}
	
	@Override
	public int read() throws IOException {
		return 0;
	}
	
	protected String getHeader() {
		return String.format("%n--%s%nContent-type: %s%nContent-Length: %d%n%n", boundary, contentType, frame.length);
	}
}